import './agent-select.css';
import {Link, useNavigate} from "react-router-dom";
import {Breadcrumb, Button, Divider, Image, Radio, RadioChangeEvent} from "antd";
import CardAgent from "../../components/card/CardAgent.tsx";
import {errorImage} from "../../util/CommonUtil.ts";
import {useState} from "react";
import {AgentMedalEnum} from "../../interfaces/card/ICardProj.ts";
import NoData from '../../assets/no-data.png';

export default function AgentSelect() {
    const [value, setValue] = useState(1);
    const nav = useNavigate();
    // const params = useParams();
    const height = window.innerHeight - 150;

    const [selectedAgentId, setSelectedAgentId] = useState('0');
    const [selectedAgent, setSelectedAgent] = useState({});

    // 列表
    const [agentList, setAgentList] = useState([{
        id: '1',
        logo: '1',
        name: '标题1',
        desc: '描述1',
        medal: AgentMedalEnum.GOLD,
        certificateImg: '1',
        selected: false
    }, {
        id: '2',
        logo: '2',
        name: '标题2',
        desc: '描述2',
        medal: AgentMedalEnum.GOLD,
        certificateImg: '1',
        selected: false
    }]);

    const renderAgent = () => {
        return agentList.map((item, index) => {
            return (
                <CardAgent key={`agent${index}`} logo={item.logo}
                           name={item.name}
                           desc={item.desc}
                           medal={item.medal}
                           certificateImg={item.certificateImg}
                           selected={selectedAgentId == item.id}
                           handleSelect={() => {
                               setSelectedAgentId(item.id);
                               setSelectedAgent(item);
                           }}
                />
            )
        })
    }

    const renderSelectedAgent = () => {
        if (Object.keys(selectedAgent).length == 0) {
            return (
                <>
                    <div className="no-data">
                        <Image src={NoData}/>
                        <span>请选择左侧机构</span>
                    </div>
                </>
            )
        }
        return (
            <>
                <div className="agent-info">
                    <div className="agent-title">机构信息</div>
                    <div className="agent-body">
                        <div className="agent-name">北京九思恒源科技有限公司</div>
                        <div className="agent-desc">
                            雄厚的技术与人才实力，赢得了客户的深厚信赖，获得了政府部门的高度认可，公司先后荣获“全国重合同守信用单位”、“先进施工企业”、“长沙市利税大户”等诸多荣誉称号。与此同时，公司承建的湖南中联重科起重机厂钢结构厂房、三一重工娄底基地车间、北京资源集团宁乡基地车间、双胞胎饲料集团长沙基地厂房、南昌西客站高铁钢结构候客大厅、江西送变电建设中超公司厂房等一大批各类钢结构优质工程，缔造了“鼎盛钢构”卓尔不群的品牌知名度和美誉度。
                        </div>
                        <Divider dashed style={{
                            marginTop: '10px',
                            marginBottom: '10px'
                        }}/>
                        <div className="agent-img-title">机构证书</div>
                        <div className="agent-img-list">
                            <Image width={270}
                                   height={170}
                                   fallback={errorImage}
                            />
                            <Image width={270}
                                   height={170}
                                   fallback={errorImage}
                            />
                            <Image width={270}
                                   height={170}
                                   fallback={errorImage}
                            />
                            <Image width={270}
                                   height={170}
                                   fallback={errorImage}
                            />
                        </div>
                        <Divider dashed style={{
                            marginTop: '10px',
                            marginBottom: '10px'
                        }}/>
                        <div className="agent-contact">
                            <div className="line">
                                <span>联系人：XXXXXX</span>
                                <span>联系电话：13888888888</span>
                            </div>
                            <div className="line">
                                <span>联系地址：内蒙古呼和浩特新城区XXXXXX</span>
                            </div>
                        </div>
                    </div>
                </div>
                <div className="agent-price">
                    <span className="label">价格种类：</span>
                    <Radio.Group onChange={(e: RadioChangeEvent) => {
                        console.log('radio checked', e.target.value);
                        setValue(e.target.value);
                    }} value={value}>
                        <Radio value={1}>普通件：200</Radio>
                        <Radio value={2}>加急件：400</Radio>
                    </Radio.Group>
                </div>
                <div style={{marginTop: '15px', textAlign: 'center'}}>
                    <Button type="primary" style={{backgroundColor: 'var(--color-primary)'}}>选择</Button>
                </div>
            </>
        )
    }

    return (
        <>
            <Breadcrumb
                items={[
                    {title: <Link to="/">首页</Link>},
                    {title: <Link to="/proj-create">创建项目</Link>},
                    {
                        title: <a href="/#" onClick={(e) => {
                            e.preventDefault();
                            nav(-1)
                        }}>编辑项目</a>
                    },
                    {title: '找代理'},
                ]}
            />
            <div className="agent-select" style={{height: `${height}px`}}>
                <div className="agent-select-left">
                    <div className="list">
                        <div className="list-item">
                            {renderAgent()}
                        </div>
                        <div className="load">
                            <Button type="text" onClick={() => {
                                setAgentList([
                                    ...agentList,
                                    {
                                        id: '3',
                                        logo: '3',
                                        name: '标题3',
                                        desc: '描述3',
                                        medal: AgentMedalEnum.SILVER,
                                        certificateImg: '3',
                                        selected: false
                                    }
                                ])
                            }}>加载更多...</Button>
                        </div>
                    </div>
                </div>
                <div className="agent-select-right">{renderSelectedAgent()}</div>
            </div>
        </>

    )
}